@@ -4,20 +4,31 @@ import os
 import sys
 import time
 import traceback
-from typing import Tuple, List, Optional, Collection
 from difflib import unified_diff
+from typing import Collection, List, Optional, Tuple
 
 import astor
 
 from flynt import state
 from flynt.cli_messages import farewell_message
-from flynt.process import fstringify_code_by_line, fstringify_concats
+from flynt.process import (
+    fstringify_code_by_line,
+    fstringify_concats,
+    fstringify_static_joins,
+)
 
 blacklist = {".tox", "venv", "site-packages", ".eggs"}
 
 
 def _fstringify_file(
-    filename, multiline, len_limit, transform_concat=False
+    filename: str,
+    multiline: bool,
+    len_limit: int,
+    *,
+    transform_concat: bool = False,
+    transform_format: bool = True,
+    transform_join: bool = False,
+    transform_percent: bool = True,
 ) -> Tuple[bool, int, int, int]:
     """
     :return: tuple: (changes_made, n_changes,
@@ -47,15 +58,28 @@ def _fstringify_file(
         return default_result()
 
     try:
-        new_code, changes = fstringify_code_by_line(
-            contents, multiline=multiline, len_limit=len_limit
-        )
+        new_code = contents
+        changes = 0
+        if transform_percent or transform_format:
+            new_code, changes = fstringify_code_by_line(
+                contents,
+                multiline=multiline,
+                len_limit=len_limit,
+                transform_percent=transform_percent,
+                transform_format=transform_format,
+            )
         if transform_concat:
             new_code, concat_changes = fstringify_concats(
                 new_code, multiline=multiline, len_limit=len_limit
             )
             changes += concat_changes
             state.concat_changes += concat_changes
+        if transform_join:
+            new_code, join_changes = fstringify_static_joins(
+                new_code, multiline=multiline, len_limit=len_limit
+            )
+            changes += join_changes
+            state.join_changes += join_changes
 
     except Exception as e:
         if not state.quiet:
@@ -89,10 +113,10 @@ def _fstringify_file(
         return default_result()
 
     if state.dry_run:
-        for l in unified_diff(
+        diff = unified_diff(
             contents.split("\n"), new_code.split("\n"), fromfile=filename
-        ):
-            print(l)
+        )
+        print("\n".join(diff))
     else:
         mode = "w"
         if bom is not None:
@@ -105,7 +129,16 @@ def _fstringify_file(
     return True, changes, len(contents), len(new_code)
 
 
-def fstringify_files(files, multiline, len_limit, transform_concat):
+def fstringify_files(
+    files,
+    multiline,
+    len_limit,
+    transform_concat: bool = False,
+    transform_join: bool = False,
+    *,
+    transform_format: bool = True,
+    transform_percent: bool = True,
+):
     changed_files = 0
     total_charcount_original = 0
     total_charcount_new = 0
@@ -117,7 +150,15 @@ def fstringify_files(files, multiline, len_limit, transform_concat):
             count_expressions,
             charcount_original,
             charcount_new,
-        ) = _fstringify_file(path, multiline, len_limit, transform_concat)
+        ) = _fstringify_file(
+            path,
+            multiline,
+            len_limit,
+            transform_concat=transform_concat,
+            transform_format=transform_format,
+            transform_join=transform_join,
+            transform_percent=transform_percent,
+        )
         if changed:
             changed_files += 1
             total_expressions += count_expressions
@@ -182,6 +223,14 @@ def _print_report(
         else:
             print("No concatenations attempted.")
 
+        if state.join_candidates:
+            print(
+                f"Static string joins attempted:             {state.join_changes}/"
+                f"{state.join_candidates} ({state.join_changes / state.join_candidates:.1%})"
+            )
+        else:
+            print("No static string joins attempted.")
+
         print(f"F-string expressions created:              {total_expr}")
 
         if state.invalid_conversions:
@@ -190,7 +239,7 @@ def _print_report(
             )
             print("To find out specific error messages, use --verbose flag.")
 
-    print("\n" + ("_-_." * 25))
+    print(f"\n{'_-_.' * 25}")
     print(farewell_message)
 
 
@@ -199,10 +248,13 @@ def fstringify(
     multiline: bool,
     len_limit: int,
     fail_on_changes: bool = False,
+    transform_percent: bool = True,
+    transform_format: bool = True,
     transform_concat: bool = False,
+    transform_join: bool = False,
     excluded_files_or_paths: Optional[Collection[str]] = None,
 ) -> int:
-    """ determine if a directory or a single file was passed, and f-stringify it."""
+    """determine if a directory or a single file was passed, and f-stringify it."""
 
     files = _resolve_files(files_or_paths, excluded_files_or_paths)
 
@@ -210,7 +262,10 @@ def fstringify(
         files,
         multiline=multiline,
         len_limit=len_limit,
+        transform_percent=transform_percent,
+        transform_format=transform_format,
         transform_concat=transform_concat,
+        transform_join=transform_join,
     )
 
     if fail_on_changes:
@@ -248,7 +303,7 @@ def _resolve_files(
 
 
 def encoding_by_bom(path, default="utf-8") -> Tuple[str, Optional[bytes]]:
-    """Adapted from https://stackoverflow.com/questions/13590749/reading-unicode-file-data-with-bom-chars-in-python/24370596#24370596 """
+    """Adapted from https://stackoverflow.com/questions/13590749/reading-unicode-file-data-with-bom-chars-in-python/24370596#24370596"""
 
     with open(path, "rb") as f:
         raw = f.read(4)  # will read less if the file is smaller
