@@ -2,8 +2,6 @@
 
 import ast
 
-import astor
-
 from flynt.format import QuoteTypes
 
 
@@ -40,7 +38,12 @@ class AstChunk:
         return QuoteTypes.double
 
     def __str__(self):
-        return astor.to_source(self.node)[1:-2]
+        from flynt.utils import ast_to_string
+
+        src = ast_to_string(self.node)
+        if src.startswith("(") and src.endswith(")"):
+            src = src[1:-1]
+        return src
 
     def __repr__(self):
-        return "AstChunk: " + str(self)
+        return f"AstChunk: {self}"
