@@ -4,9 +4,8 @@ import argparse
 import sys
 import warnings
 
+from flynt import __version__, state
 from flynt.api import fstringify, fstringify_code_by_line
-from flynt import state
-from flynt import __version__
 from flynt.pyproject_finder import find_pyproject_toml, parse_pyproject_toml
 
 
@@ -14,10 +13,12 @@ def main():
     return sys.exit(run_flynt_cli())
 
 
-def run_flynt_cli():
+def run_flynt_cli(arglist=None):
     """"""
     parser = argparse.ArgumentParser(
-        description=f"flynt v.{__version__}", add_help=True
+        prog="flynt",
+        description=f"flynt v.{__version__}",
+        add_help=True,
     )
 
     verbosity_group = parser.add_mutually_exclusive_group()
@@ -29,7 +30,11 @@ def run_flynt_cli():
         default=False,
     )
     verbosity_group.add_argument(
-        "-q", "--quiet", action="store_true", help="run without output", default=False
+        "-q",
+        "--quiet",
+        action="store_true",
+        help="run without stdout output",
+        default=False,
     )
 
     multiline_group = parser.add_mutually_exclusive_group()
@@ -68,6 +73,24 @@ def run_flynt_cli():
         "The snippet must use single quotes or escaped double quotes. ",
     )
 
+    parser.add_argument(
+        "--no-tp",
+        "--no-transform-percent",
+        dest="transform_percent",
+        action="store_false",
+        default=True,
+        help="Don't transform %% formatting to f-strings (default: do so)",
+    )
+
+    parser.add_argument(
+        "--no-tf",
+        "--no-transform-format",
+        dest="transform_format",
+        action="store_false",
+        default=True,
+        help="Don't transform .format formatting to f-strings (default: do so)",
+    )
+
     parser.add_argument(
         "-tc",
         "--transform-concats",
@@ -77,6 +100,15 @@ def run_flynt_cli():
         "with f-strings. Available only if flynt is installed with 3.8+ interpreter.",
     )
 
+    parser.add_argument(
+        "-tj",
+        "--transform-joins",
+        action="store_true",
+        default=False,
+        help="Replace static joins (where the joiner is a string literal and the joinee is a static-length list) "
+        "with f-strings. Available only if flynt is installed with 3.8+ interpreter.",
+    )
+
     parser.add_argument(
         "-f",
         "--fail-on-change",
@@ -111,7 +143,7 @@ def run_flynt_cli():
         default=False,
         help="Print the current version number and exit.",
     )
-    args = parser.parse_args()
+    args = parser.parse_args(arglist)
 
     if args.version:
         print(__version__)
@@ -121,6 +153,28 @@ def run_flynt_cli():
         parser.print_usage()
         return 1
 
+    if args.transform_concats and sys.version_info < (3, 8):
+        raise Exception(
+            f"""Transforming string concatenations is only possible with flynt
+                installed to a python3.8+ interpreter. Currently using {sys.version_info}."""
+        )
+
+    if args.transform_joins and sys.version_info < (3, 8):
+        raise Exception(
+            f"""Transforming joins is only possible with flynt
+                installed to a python3.8+ interpreter. Currently using {sys.version_info}."""
+        )
+
+    if args.string:
+        set_global_state(args)
+        converted, _ = fstringify_code_by_line(
+            " ".join(args.src),
+            multiline=not args.no_multiline,
+            len_limit=int(args.line_length),
+        )
+        print(converted)
+        return 0
+
     salutation = f"Running flynt v.{__version__}"
     toml_file = find_pyproject_toml(tuple(args.src))
     if toml_file:
@@ -136,42 +190,29 @@ def run_flynt_cli():
                 f"Supported options are: {supported_args}"
             )
         parser.set_defaults(**cfg)
-        args = parser.parse_args()
-
-    if not args.string:
+        args = parser.parse_args(arglist)
+    set_global_state(args)
+    if not args.quiet:
         print(salutation)
-
+    if args.verbose:
+        print(f"Using following options: {args}")
     if args.dry_run:
         print("Running flynt in dry-run mode. No files will be changed.")
+    return fstringify(
+        args.src,
+        excluded_files_or_paths=args.exclude,
+        multiline=not args.no_multiline,
+        len_limit=int(args.line_length),
+        fail_on_changes=args.fail_on_change,
+        transform_percent=args.transform_percent,
+        transform_format=args.transform_format,
+        transform_concat=args.transform_concats,
+        transform_join=args.transform_joins,
+    )
 
-    if args.transform_concats and sys.version_info < (3, 8):
-        raise Exception(
-            f"""Transforming string concatenations is only possible with flynt
-                installed to a python3.8+ interpreter. Currently using {sys.version_info}."""
-        )
-
-    if args.verbose and not args.string:
-        print(f"Using following options: {args}")
 
+def set_global_state(args):
     state.aggressive = args.aggressive
     state.verbose = args.verbose
     state.quiet = args.quiet
     state.dry_run = args.dry_run
-
-    if args.string:
-        converted, _ = fstringify_code_by_line(
-            " ".join(args.src),
-            multiline=not args.no_multiline,
-            len_limit=int(args.line_length),
-        )
-        print(converted)
-        return 0
-    else:
-        return fstringify(
-            args.src,
-            excluded_files_or_paths=args.exclude,
-            multiline=not args.no_multiline,
-            len_limit=int(args.line_length),
-            fail_on_changes=args.fail_on_change,
-            transform_concat=args.transform_concats,
-        )
