@@ -30,7 +30,9 @@ def get_quote_type(code: str):
 
 def remove_quotes(code: str):
     quote_type = get_quote_type(code)
-    return code[len(quote_type) : -len(quote_type)]
+    if quote_type:
+        return code[len(quote_type) : -len(quote_type)]
+    return code
 
 
 def set_quote_type(code: str, quote_type: str):
@@ -40,7 +42,7 @@ def set_quote_type(code: str, quote_type: str):
         prefix, body = "", remove_quotes(code)
     if quote_type in (QuoteTypes.single, QuoteTypes.triple_double):
         if body[-2:] == '\\"':
-            body = body[:-2] + '"'
+            body = f'{body[:-2]}"'
     elif quote_type is QuoteTypes.double:
         body = lonely_quote.sub('\\"', body)
 
