@@ -1,15 +1,19 @@
 import math
 import re
-from typing import Callable, Tuple
 import string
+from functools import partial
+from typing import Callable, Tuple
 
 from flynt import lexer, state
 from flynt.exceptions import FlyntException
 from flynt.format import QuoteTypes as qt
 from flynt.format import get_quote_type
 from flynt.lexer import split
+from flynt.static_join.candidates import join_candidates
+from flynt.static_join.transformer import transform_join
+from flynt.string_concat.candidates import concat_candidates
+from flynt.string_concat.transformer import transform_concat
 from flynt.transform.transform import transform_chunk
-from flynt.string_concat import concat_candidates, transform_concat
 
 noqa_regex = re.compile("#[ ]*noqa.*flynt")
 
@@ -106,12 +110,12 @@ class JoinTransformer:
                 lines = converted.split("\\n")
                 lines[-1] += rest
                 lines_fit = all(
-                    len(l) <= self.len_limit - chunk.start_idx for l in lines
+                    len(line) <= self.len_limit - chunk.start_idx for line in lines
                 )
                 converted = converted.replace("\\n", "\n")
             else:
                 lines_fit = (
-                    len("".join([converted, rest])) <= self.len_limit - chunk.start_idx
+                    len(f"{converted}{rest}") <= self.len_limit - chunk.start_idx
                 )
 
         else:
@@ -160,24 +164,40 @@ class JoinTransformer:
             self.last_line += 1
 
 
-def fstringify_code_by_line(code: str, multiline=True, len_limit=88) -> Tuple[str, int]:
-    """ returns fstringified version of the code and amount of lines edited."""
+def fstringify_code_by_line(
+    code: str,
+    multiline=True,
+    len_limit=88,
+    transform_percent: bool = True,
+    transform_format: bool = True,
+) -> Tuple[str, int]:
+    """returns fstringified version of the code and amount of lines edited."""
+    phunk = partial(
+        transform_chunk,
+        transform_format=transform_format,
+        transform_percent=transform_percent,
+    )
     return _transform_code(
-        code, split.get_fstringify_chunks, transform_chunk, multiline, len_limit
+        code, split.get_fstringify_chunks, phunk, multiline, len_limit
     )
 
 
 def fstringify_concats(code: str, multiline=True, len_limit=88) -> Tuple[str, int]:
-    """ replace string literal concatenations with f-string expressions. """
+    """replace string literal concatenations with f-string expressions."""
     return _transform_code(
         code, concat_candidates, transform_concat, multiline, len_limit
     )
 
 
+def fstringify_static_joins(code: str, multiline=True, len_limit=88) -> Tuple[str, int]:
+    """replace joins on static content with f-string expressions."""
+    return _transform_code(code, join_candidates, transform_join, multiline, len_limit)
+
+
 def _transform_code(
     code: str, candidates_iter_factory, transform_func, multiline, len_limit
 ) -> Tuple[str, int]:
-    """ returns fstringified version of the code and amount of lines edited."""
+    """returns fstringified version of the code and amount of lines edited."""
 
     len_limit = _multiline_settings(len_limit, multiline)
     jt = JoinTransformer(code, len_limit, candidates_iter_factory, transform_func)
