@@ -3,20 +3,11 @@ from typing import List
 
 from flynt import state
 from flynt.ast_chunk import AstChunk
-
-
-def is_str_literal(node):
-    """ Returns True if a node is a string literal """
-    if isinstance(node, ast.Constant):
-        return isinstance(node.value, str)
-    elif isinstance(node, ast.JoinedStr):
-        return True
-    else:
-        return False
+from flynt.utils import is_str_literal
 
 
 def is_string_concat(node):
-    """ Returns True for nodes representing a string concatenation """
+    """Returns True for nodes representing a string concatenation"""
     if is_str_literal(node):
         return True
     if isinstance(node, ast.BinOp) and isinstance(node.op, ast.Add):
