@@ -1,31 +1,12 @@
 import ast
-import sys
 import string
+import sys
 from collections import deque
 from typing import Tuple, Union
 
-import astor
-
 from flynt import state
-from flynt.exceptions import FlyntException, ConversionRefused
-
-
-def ast_formatted_value(
-    val, fmt_str: str = None, conversion=None
-) -> ast.FormattedValue:
-
-    if astor.to_source(val)[0] == "{":
-        raise FlyntException(
-            "values starting with '{' are better left not transformed."
-        )
-
-    format_spec = ast.JoinedStr([ast_string_node(fmt_str)]) if fmt_str else None
-    conversion = -1 if conversion is None else ord(conversion.replace("!", ""))
-    return ast.FormattedValue(value=val, conversion=conversion, format_spec=format_spec)
-
-
-def ast_string_node(string: str) -> ast.Str:
-    return ast.Str(s=string)
+from flynt.exceptions import ConversionRefused, FlyntException
+from flynt.utils import ast_formatted_value, ast_string_node
 
 
 def matching_call(node) -> bool:
@@ -52,7 +33,7 @@ stdlib_parse = string.Formatter().parse
 
 
 def joined_string(fmt_call: ast.Call) -> Tuple[Union[ast.JoinedStr, ast.Str], bool]:
-    """ Transform a "...".format() call node into a f-string node. """
+    """Transform a "...".format() call node into a f-string node."""
 
     string = fmt_call.func.value.s
     var_map = {kw.arg: kw.value for kw in fmt_call.keywords}
