@@ -2,9 +2,9 @@ import ast
 import re
 from collections import deque
 
-from flynt.exceptions import FlyntException, ConversionRefused
-from flynt.transform.format_call_transforms import ast_formatted_value, ast_string_node
 from flynt import state
+from flynt.exceptions import ConversionRefused, FlyntException
+from flynt.transform.format_call_transforms import ast_formatted_value, ast_string_node
 
 FORMATS = "diouxXeEfFgGcrsa"
 
@@ -26,6 +26,14 @@ conversion_methods = {"r": "!r", "a": "!a", "s": None}
 integer_specificers = "dxXob"
 
 
+def is_percent_stringify(node: ast.BinOp) -> bool:
+    return (
+        isinstance(node.left, ast.Str)
+        and isinstance(node.op, ast.Mod)
+        and isinstance(node.right, tuple([ast.Tuple, ast.Dict, *supported_operands]))
+    )
+
+
 def formatted_value(fmt_prefix, fmt_spec, val):
     if fmt_spec in integer_specificers:
         fmt_prefix = fmt_prefix.replace(".", "0")
