@@ -3,22 +3,26 @@ import copy
 import traceback
 from typing import Tuple
 
-import astor
-
 from flynt import state
-from flynt.exceptions import FlyntException, ConversionRefused
-from flynt.format import QuoteTypes, set_quote_type
+from flynt.exceptions import ConversionRefused, FlyntException
+from flynt.format import QuoteTypes
 from flynt.transform.FstringifyTransformer import fstringify_node
+from flynt.utils import fixup_transformed
 
 
 def transform_chunk(
-    code: str, quote_type: str = QuoteTypes.triple_double
+    code: str,
+    quote_type: str = QuoteTypes.triple_double,
+    transform_percent: bool = True,
+    transform_format: bool = True,
 ) -> Tuple[str, bool]:
     """Convert a block of code to an f-string
 
     Args:
         code: The code to convert.
         quote_type: the quote type to use for the transformed result
+        transform_percent: whether to transform percent format strings
+        transform_format: whether to transform format calls
 
     Returns:
        Tuple: resulting code, boolean: was it changed?
@@ -26,7 +30,11 @@ def transform_chunk(
 
     try:
         tree = ast.parse(code)
-        converted, changed, str_in_str = fstringify_node(copy.deepcopy(tree))
+        converted, changed, str_in_str = fstringify_node(
+            copy.deepcopy(tree),
+            transform_percent=transform_percent,
+            transform_format=transform_format,
+        )
     except (SyntaxError, FlyntException, Exception) as e:
         if state.verbose:
             if isinstance(e, ConversionRefused):
@@ -38,13 +46,9 @@ def transform_chunk(
         return code, False
     else:
         if changed:
-            new_code = astor.to_source(converted)
-            new_code = new_code.strip()
             if str_in_str and quote_type == QuoteTypes.single:
                 quote_type = QuoteTypes.double
-            new_code = set_quote_type(new_code, quote_type)
-            new_code = new_code.replace("\n", "\\n")
-            new_code = new_code.replace("\t", "\\t")
+            new_code = fixup_transformed(converted, quote_type=quote_type)
             try:
                 ast.parse(new_code)
             except SyntaxError as e:
